@@ -9,6 +9,7 @@ from tzlocal import get_localzone
 
 local_tz = get_localzone()  # get the local timezone
 
+IGLU_R_COMPATIBLE = True
 
 def localize_naive_timestamp(timestamp: datetime) -> datetime:
     """
@@ -28,8 +29,12 @@ def set_local_tz(tz: str) -> None:
     global local_tz
     local_tz = ZoneInfo(tz)
 
+def get_local_tz() :
+    global local_tz
+    return local_tz
 
-def check_data_columns(data: pd.DataFrame, tz="") -> pd.DataFrame:
+
+def check_data_columns(data: pd.DataFrame, time_check=False, tz="") -> pd.DataFrame:
     """
     Check if the input DataFrame has the required columns and correct data types.
 
@@ -58,6 +63,9 @@ def check_data_columns(data: pd.DataFrame, tz="") -> pd.DataFrame:
     if missing_cols:
         raise ValueError(f"Missing required columns: {missing_cols}")
 
+    # Create a copy to avoid dtype warning
+    data = data.copy()
+
     # Check data types
     if not pd.api.types.is_numeric_dtype(data["gl"]):
         try:
@@ -86,9 +94,6 @@ def check_data_columns(data: pd.DataFrame, tz="") -> pd.DataFrame:
     if data["gl"].isna().any():
         warnings.warn("Data contains missing glucose values")
 
-    # convert time to datetime
-    data.loc[:, "time"] = pd.to_datetime(data["time"])
-
     # convert time to specified timezone
     # TODO: check if this is correct (R-implementation compatibility)
     # if tz and tz != "":
@@ -97,8 +102,12 @@ def check_data_columns(data: pd.DataFrame, tz="") -> pd.DataFrame:
     #
     # this is implementation compatible with R implementation
     # but seems incorrect, as it convert time to TZ instead of localizing it to TZ
-    if tz and tz != "":
-        data["time"] = data["time"].apply(localize_naive_timestamp).dt.tz_convert(tz)
+    if tz != "":
+        # Create a copy to avoid dtype warning and properly handle timezone conversion
+        data["time"] = pd.to_datetime(data["time"]).apply(localize_naive_timestamp).dt.tz_convert(tz)
+    else:
+        # Create a copy to avoid dtype warning
+        data["time"] = pd.to_datetime(data["time"]).apply(localize_naive_timestamp)
 
     return data
 
@@ -108,7 +117,7 @@ def CGMS2DayByDay(
     dt0: Optional[pd.Timestamp] = None,
     inter_gap: int = 45,
     tz: str = "",
-) -> Tuple[np.ndarray, list, int, list]:
+) -> Tuple[np.ndarray, list, int]:
     """
     Interpolate glucose values onto an equally spaced grid from day to day.
 
@@ -151,10 +160,6 @@ def CGMS2DayByDay(
     # Check data format
     data = check_data_columns(data, tz)
 
-    # # Convert timezone if specified
-    # if tz and tz!= "":
-    #     data['time'] = data['time'].dt.tz_localize(tz)
-
     # Get unique subjects
     subjects = data["id"].unique()
     if len(subjects) > 1:
@@ -173,10 +178,14 @@ def CGMS2DayByDay(
     start_time = data["time"].min().floor("D")
     end_time = data["time"].max().ceil("D")
     time_grid = pd.date_range(
-        start=start_time + pd.Timedelta(minutes=dt0), end=end_time, freq=f"{dt0}min"
+        start=start_time, end=end_time, freq=f"{dt0}min"
     )
-    # remove last time point
-    # time_grid = time_grid[:-1]
+    if IGLU_R_COMPATIBLE:
+        # remove the first time point
+        time_grid = time_grid[1:]
+    else:
+        # remove the last time point
+        time_grid = time_grid[:-1]
 
     # find gaps in the data (using original data indexes, not time grid)
     gaps = []
@@ -225,6 +234,10 @@ def CGMS2DayByDay(
     interp_data = interp_data.reshape(n_days, n_points_per_day)
 
     # Get actual dates
+    if IGLU_R_COMPATIBLE:
+        # convert start_time into naive datetime
+        start_time = start_time.tz_localize(None)
+        
     actual_dates = [start_time + pd.Timedelta(days=i) for i in range(n_days)]
 
     return interp_data, actual_dates, dt0
@@ -245,4 +258,4 @@ def gd2d_to_df(gd2d, actual_dates, dt0):
             "gl": pd.Series(gl, dtype='float64')
         })
 
-    return df
\ No newline at end of file
+    return df
