@@ -64,7 +64,7 @@ def test_mag_iglu_r_compatible(scenario):
         check_freq=True,
         check_flags=True,
         check_exact=False,
-        rtol=1e-1,
+        rtol=0.001,
     )
 
 
