@@ -69,7 +69,7 @@ def test_mage_iglu_r_compatible(scenario):
         check_freq=True,
         check_flags=True,
         check_exact=False,
-        rtol=0.2,
+        rtol=0.001,
     )
 
 
@@ -78,26 +78,24 @@ def base_data():
     """Fixture providing base test data for MAGE calculations"""
     return pd.DataFrame(
         {
-            "id": [
-                "subject1",
-                "subject1",
-                "subject1",
-                "subject1",
-                "subject2",
-                "subject2"
-            ],
+            "id": ["subject1"] * 8 + ["subject2"]*2,
             "time": pd.to_datetime(
                 [
+                    "2020-01-01 00:00:00",
+                    "2020-01-01 00:20:00",
+                    "2020-01-01 00:40:00",
+                    "2020-01-01 01:00:00",
+                    "2020-01-01 01:20:00",
+                    "2020-01-01 01:40:00",
+                    "2020-01-01 02:00:00",
+                    "2020-01-01 02:20:00",
+
                     "2020-01-01 00:00:00",  # 0 min
                     "2020-01-01 00:05:00",  # 5 min
-                    "2020-01-01 00:10:00",  # 10 min
-                    "2020-01-01 00:15:00",  # 15 min
-                    "2020-01-01 00:00:00",  # subject2
-                    "2020-01-01 00:05:00",  # subject2
 
                 ]
             ),
-            "gl": [150, 200, 180, 160, 140, 190],
+            "gl": [150, 200, 180, 160, 140, 190, 170, 210] + [150, 200],
         }
     )
 
@@ -111,13 +109,13 @@ def multi_point_data():
             "time": pd.to_datetime(
                 [
                     "2020-01-01 00:00:00",
-                    "2020-01-01 00:05:00",
-                    "2020-01-01 00:10:00",
-                    "2020-01-01 00:15:00",
                     "2020-01-01 00:20:00",
-                    "2020-01-01 00:25:00",
-                    "2020-01-01 00:30:00",
-                    "2020-01-01 00:35:00",
+                    "2020-01-01 00:40:00",
+                    "2020-01-01 01:00:00",
+                    "2020-01-01 01:20:00",
+                    "2020-01-01 01:40:00",
+                    "2020-01-01 02:00:00",
+                    "2020-01-01 02:20:00",
                 ]
             ),
             "gl": [150, 200, 180, 160, 140, 190, 170, 210],
@@ -170,7 +168,7 @@ def test_mage_constant_glucose():
     )
     result = iglu.mage(single_subject)
     assert len(result) == 1
-    assert result["MAGE"].iloc[0] == 0
+    assert np.isnan(result["MAGE"].iloc[0])
 
 
 def test_mage_missing_values():
